land_cover_color_mapping = {
    "No data": "#D3D3D3",
    "Cropland, rainfed": "#F7C6C7",
    "Cropland, rainfed, herbaceous cover": "#F7B7A3",
    "Cropland, rainfed, tree, or shrub cover": "#F7A8A2",
    "Cropland, irrigated or post-flooding": "#E5F2B3",
    "Mosaic cropland (>50%) / natural vegetation (tree, shrub, herbaceous cover) (<50%)": "#D0E8A4",
    "Mosaic natural vegetation (tree, shrub, herbaceous cover) (>50%) / cropland (<50%)": "#B0D9A0",
    "Tree cover, broadleaved, evergreen, closed to open (>15%)": "#228B22",
    "Tree cover, broadleaved, deciduous, closed to open (>15%)": "#6B8E23",
    "Tree cover, broadleaved, deciduous, closed (>40%)": "#4A7F2A",
    "Tree cover, broadleaved, deciduous, open (15-40%)": "#7A9D3C",
    "Tree cover, needleleaved, evergreen, closed to open (>15%)": "#2E8B57",
    "Tree cover, needleleaved, evergreen, closed (>40%)": "#006400",
    "Tree cover, needleleaved, evergreen, open (15-40%)": "#3C8D3F",
    "Tree cover, needleleaved, deciduous, closed to open (>15%)": "#2E8B57",
    "Tree cover, needleleaved, deciduous, closed (>40%)": "#006400",
    "Tree cover, needleleaved, deciduous, open (15-40%)": "#4B8F29",
    "Tree cover, mixed leaf type (broadleaved and needleleaved)": "#4A5D23",
    "Mosaic tree and shrub (>50%) / herbaceous cover (<50%)": "#7C9A5B",
    "Mosaic herbaceous cover (>50%) / tree and shrub (<50%)": "#9AA74A",
    "Shrubland": "#C6D8A6",
    "Evergreen shrubland": "#9ACD32",
    "Deciduous shrubland": "#A4A10C",
    "Grassland": "#C0D8A0",
    "Lichens and mosses": "#BCCF6F",
    "Sparse vegetation (tree, shrub, herbaceous cover) (<15%)": "#C1D1C3",
    "Sparse tree (<15%)": "#C3D8B0",
    "Sparse shrub (<15%)": "#D5E1A1",
    "Sparse herbaceous cover (<15%)": "#E2F3A4",
    "Tree cover, flooded, fresh or brackish water": "#A4C8E2",
    "Tree cover, flooded, saline water": "#7A9ACD",
    "Shrub or herbaceous cover, flooded, fresh/saline/brackish water": "#9BC9F4",
    "Urban areas": "#A9A9A9",
    "Bare areas": "#D2B48C",
    "Consolidated bare areas": "#C8A36A",
    "Unconsolidated bare areas": "#F4A460",
    "Water bodies": "#4682B4",
    "Permanent snow and ice": "#FFFFFF",
    "No Data": "#D3D3D3",
    "Water": "#4682B4",
    "Trees": "#228B22",
    "Flooded vegetation": "#A4C8E2",
    "Crops": "#F7C6C7",
    "Built area": "#A9A9A9",
    "Bare ground": "#D2B48C",
    "Snow/ice": "#FFFFFF",
    "Clouds": "#C0C0C0",
    "Rangeland": "#C0D8A0",
    "(?)": "white",
    "low risk": "green",
    "medium risk": "orange",
    "high risk": "#C8102E",
}